Documentation
¶
Index ¶
- Constants
- func Debug(msg string, args ...any)
- func Error(msg string, args ...any)
- func Info(msg string, args ...any)
- func New(_conf *Config) writer
- func Success(msg string, args ...any)
- func Wait()
- func Warn(msg string, args ...any)
- func WriteLog(messages ...any)
- func WriteLogf(msg string, args ...any)
- type Config
Constants ¶
const ( Unknown _type = iota DEBUG INFO WARN ERROR )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// Stop the Log Printing in the console useful for production environment
NoLog bool `env:"NO_GULOG" arg:"no-gulog" default:"false"`
// it let the user decide how he want to see the log supported formats are only json and plain texts now
Format string `env:"GULOG_FORMAT" arg:"gulog-format" default:"text"`
// a file name where user want to store the log, by default it is empty meens user do not want to create logs
File string `env:"GULOG_LOGFIE" arg:"gulog-logfile" default:""`
}
Click to show internal directories.
Click to hide internal directories.